pub struct ForkByErrorProvider<P0, P1, F>(P0, P1, F);Expand description
A provider that returns data from one of two child providers based on a predicate function.
This is an abstract forking provider that must be provided with a type implementing the
ForkByErrorPredicate trait.
ForkByErrorProvider does not support forking between DataProviders. However, it
supports forking between BufferProvider, and DynamicDataProvider.
Tuple Fields
0: P01: P12: FImplementations
Sourceimpl<P0, P1, F> ForkByErrorProvider<P0, P1, F>
impl<P0, P1, F> ForkByErrorProvider<P0, P1, F>
Sourcepub fn new_with_predicate(p0: P0, p1: P1, predicate: F) -> Self
pub fn new_with_predicate(p0: P0, p1: P1, predicate: F) -> Self
Create a new provider that forks between the two children.
The predicate argument should be an instance of a struct implementing
ForkByErrorPredicate.
Sourcepub fn inner_mut(&mut self) -> (&mut P0, &mut P1)
pub fn inner_mut(&mut self) -> (&mut P0, &mut P1)
Returns mutable references to the inner providers.
Sourcepub fn into_inner(self) -> (P0, P1)
pub fn into_inner(self) -> (P0, P1)
Returns ownership of the inner providers to the caller.
Sourceimpl<P0, P1> ForkByErrorProvider<P0, P1, MarkerNotFoundPredicate>
impl<P0, P1> ForkByErrorProvider<P0, P1, MarkerNotFoundPredicate>
Sourcepub fn new(p0: P0, p1: P1) -> Self
pub fn new(p0: P0, p1: P1) -> Self
A provider that returns data from one of two child providers based on the marker.
See ForkByMarkerProvider.