pub struct MultiForkByErrorProvider<P, F> {
providers: Vec<P>,
predicate: F,
}Expand description
A provider that returns data from the first child provider passing a predicate function.
This is an abstract forking provider that must be provided with a type implementing the
ForkByErrorPredicate trait.
MultiForkByErrorProvider does not support forking between DataProviders. However, it
supports forking between BufferProvider, and DynamicDataProvider.
Fields
providers: Vec<P>predicate: FImplementations
Sourceimpl<P, F> MultiForkByErrorProvider<P, F>
impl<P, F> MultiForkByErrorProvider<P, F>
Sourcepub fn new_with_predicate(providers: Vec<P>, predicate: F) -> Self
pub fn new_with_predicate(providers: Vec<P>, predicate: F) -> Self
Create a new provider that forks between the vector of children.
The predicate argument should be an instance of a struct implementing
ForkByErrorPredicate.
Sourcepub fn with_inner_mut(&mut self, f: impl FnOnce(&mut Vec<P>))
pub fn with_inner_mut(&mut self, f: impl FnOnce(&mut Vec<P>))
Exposes a mutable vector of providers to a closure so it can be mutated.
Sourcepub fn into_inner(self) -> Vec<P>
pub fn into_inner(self) -> Vec<P>
Returns ownership of the inner providers to the caller.
Sourceimpl<P> MultiForkByErrorProvider<P, MarkerNotFoundPredicate>
impl<P> MultiForkByErrorProvider<P, MarkerNotFoundPredicate>